==> cdktf_cdktf_provider_azurerm-0.5.6-py3-none-any.whl: package/lib/data-azurerm-storage-account.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataAzurermStorageAccountConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#min_tls_version DataAzurermStorageAccount#min_tls_version}.
     *
     * @stability stable
     */
    readonly minTlsVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#name DataAzurermStorageAccount#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#resource_group_name DataAzurermStorageAccount#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#timeouts DataAzurermStorageAccount#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DataAzurermStorageAccountTimeouts;
}
/**
 * @stability stable
 */
export declare class DataAzurermStorageAccountCustomDomain extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
}
/**
 * @stability stable
 */
export interface DataAzurermStorageAccountTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#read DataAzurermStorageAccount#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
export declare function dataAzurermStorageAccountTimeoutsToTerraform(struct?: DataAzurermStorageAccountTimeoutsOutputReference | DataAzurermStorageAccountTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class DataAzurermStorageAccountTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataAzurermStorageAccountTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataAzurermStorageAccountTimeouts | undefined);
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account azurerm_storage_account}.
 *
 * @stability stable
 */
export declare class DataAzurermStorageAccount extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account azurerm_storage_account} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataAzurermStorageAccountConfig);
    /**
     * @stability stable
     */
    get accessTier(): string;
    /**
     * @stability stable
     */
    get accountKind(): string;
    /**
     * @stability stable
     */
    get accountReplicationType(): string;
    /**
     * @stability stable
     */
    get accountTier(): string;
    /**
     * @stability stable
     */
    get allowBlobPublicAccess(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    customDomain(index: string): DataAzurermStorageAccountCustomDomain;
    /**
     * @stability stable
     */
    get enableHttpsTrafficOnly(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get infrastructureEncryptionEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get isHnsEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get location(): string;
    private _minTlsVersion?;
    /**
     * @stability stable
     */
    get minTlsVersion(): string;
    /**
     * @stability stable
     */
    set minTlsVersion(value: string);
    /**
     * @stability stable
     */
    resetMinTlsVersion(): void;
    /**
     * @stability stable
     */
    get minTlsVersionInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get primaryAccessKey(): string;
    /**
     * @stability stable
     */
    get primaryBlobConnectionString(): string;
    /**
     * @stability stable
     */
    get primaryBlobEndpoint(): string;
    /**
     * @stability stable
     */
    get primaryBlobHost(): string;
    /**
     * @stability stable
     */
    get primaryConnectionString(): string;
    /**
     * @stability stable
     */
    get primaryDfsEndpoint(): string;
    /**
     * @stability stable
     */
    get primaryDfsHost(): string;
    /**
     * @stability stable
     */
    get primaryFileEndpoint(): string;
    /**
     * @stability stable
     */
    get primaryFileHost(): string;
    /**
     * @stability stable
     */
    get primaryLocation(): string;
    /**
     * @stability stable
     */
    get primaryQueueEndpoint(): string;
    /**
     * @stability stable
     */
    get primaryQueueHost(): string;
    /**
     * @stability stable
     */
    get primaryTableEndpoint(): string;
    /**
     * @stability stable
     */
    get primaryTableHost(): string;
    /**
     * @stability stable
     */
    get primaryWebEndpoint(): string;
    /**
     * @stability stable
     */
    get primaryWebHost(): string;
    /**
     * @stability stable
     */
    get queueEncryptionKeyType(): string;
    private _resourceGroupName?;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get secondaryAccessKey(): string;
    /**
     * @stability stable
     */
    get secondaryBlobConnectionString(): string;
    /**
     * @stability stable
     */
    get secondaryBlobEndpoint(): string;
    /**
     * @stability stable
     */
    get secondaryBlobHost(): string;
    /**
     * @stability stable
     */
    get secondaryConnectionString(): string;
    /**
     * @stability stable
     */
    get secondaryDfsEndpoint(): string;
    /**
     * @stability stable
     */
    get secondaryDfsHost(): string;
    /**
     * @stability stable
     */
    get secondaryFileEndpoint(): string;
    /**
     * @stability stable
     */
    get secondaryFileHost(): string;
    /**
     * @stability stable
     */
    get secondaryLocation(): string;
    /**
     * @stability stable
     */
    get secondaryQueueEndpoint(): string;
    /**
     * @stability stable
     */
    get secondaryQueueHost(): string;
    /**
     * @stability stable
     */
    get secondaryTableEndpoint(): string;
    /**
     * @stability stable
     */
    get secondaryTableHost(): string;
    /**
     * @stability stable
     */
    get secondaryWebEndpoint(): string;
    /**
     * @stability stable
     */
    get secondaryWebHost(): string;
    /**
     * @stability stable
     */
    get tableEncryptionKeyType(): string;
    /**
     * @stability stable
     */
    tags(key: string): string | cdktf.IResolvable;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DataAzurermStorageAccountTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DataAzurermStorageAccountTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataAzurermStorageAccountTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.5.60-py3-none-any.whl: package/lib/data-azurerm-storage-account.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermStorageAccountConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#min_tls_version DataAzurermStorageAccount#min_tls_version}
    */
    readonly minTlsVersion?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#name DataAzurermStorageAccount#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#resource_group_name DataAzurermStorageAccount#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#timeouts DataAzurermStorageAccount#timeouts}
    */
    readonly timeouts?: DataAzurermStorageAccountTimeouts;
}
export declare class DataAzurermStorageAccountCustomDomain extends cdktf.ComplexComputedList {
    get name(): string;
}
export interface DataAzurermStorageAccountTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account#read DataAzurermStorageAccount#read}
    */
    readonly read?: string;
}
export declare function dataAzurermStorageAccountTimeoutsToTerraform(struct?: DataAzurermStorageAccountTimeoutsOutputReference | DataAzurermStorageAccountTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermStorageAccountTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzurermStorageAccountTimeouts | undefined;
    set internalValue(value: DataAzurermStorageAccountTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account azurerm_storage_account}
*/
export declare class DataAzurermStorageAccount extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/storage_account azurerm_storage_account} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermStorageAccountConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermStorageAccountConfig);
    get accessTier(): string;
    get accountKind(): string;
    get accountReplicationType(): string;
    get accountTier(): string;
    get allowBlobPublicAccess(): cdktf.IResolvable;
    customDomain(index: string): DataAzurermStorageAccountCustomDomain;
    get enableHttpsTrafficOnly(): cdktf.IResolvable;
    get id(): string;
    get infrastructureEncryptionEnabled(): cdktf.IResolvable;
    get isHnsEnabled(): cdktf.IResolvable;
    get location(): string;
    private _minTlsVersion?;
    get minTlsVersion(): string;
    set minTlsVersion(value: string);
    resetMinTlsVersion(): void;
    get minTlsVersionInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get primaryAccessKey(): string;
    get primaryBlobConnectionString(): string;
    get primaryBlobEndpoint(): string;
    get primaryBlobHost(): string;
    get primaryConnectionString(): string;
    get primaryDfsEndpoint(): string;
    get primaryDfsHost(): string;
    get primaryFileEndpoint(): string;
    get primaryFileHost(): string;
    get primaryLocation(): string;
    get primaryQueueEndpoint(): string;
    get primaryQueueHost(): string;
    get primaryTableEndpoint(): string;
    get primaryTableHost(): string;
    get primaryWebEndpoint(): string;
    get primaryWebHost(): string;
    get queueEncryptionKeyType(): string;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get secondaryAccessKey(): string;
    get secondaryBlobConnectionString(): string;
    get secondaryBlobEndpoint(): string;
    get secondaryBlobHost(): string;
    get secondaryConnectionString(): string;
    get secondaryDfsEndpoint(): string;
    get secondaryDfsHost(): string;
    get secondaryFileEndpoint(): string;
    get secondaryFileHost(): string;
    get secondaryLocation(): string;
    get secondaryQueueEndpoint(): string;
    get secondaryQueueHost(): string;
    get secondaryTableEndpoint(): string;
    get secondaryTableHost(): string;
    get secondaryWebEndpoint(): string;
    get secondaryWebHost(): string;
    get tableEncryptionKeyType(): string;
    tags(key: string): string | cdktf.IResolvable;
    private _timeouts;
    get timeouts(): DataAzurermStorageAccountTimeoutsOutputReference;
    putTimeouts(value: DataAzurermStorageAccountTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermStorageAccountTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
